pub trait AmendmentsFields: LedgerObjectCommonFields {
// Provided methods
fn amendments(&self) -> Result<Option<[u8; 512]>> { ... }
fn previous_txn_id(&self) -> Result<Option<Hash256>> { ... }
fn previous_txn_lgr_seq(&self) -> Result<Option<u32>> { ... }
}Expand description
Trait providing access to fields specific to Amendments objects in any ledger.
Provided Methods
Sourcefn amendments(&self) -> Result<Option<[u8; 512]>>
fn amendments(&self) -> Result<Option<[u8; 512]>>
Array of 256-bit amendment IDs for all currently enabled amendments. If omitted, there are no enabled amendments. Raw bytes; VECTOR256 is not yet typed in Rust.
Sourcefn previous_txn_id(&self) -> Result<Option<Hash256>>
fn previous_txn_id(&self) -> Result<Option<Hash256>>
The identifying hash of the transaction that most recently modified this entry.
Sourcefn previous_txn_lgr_seq(&self) -> Result<Option<u32>>
fn previous_txn_lgr_seq(&self) -> Result<Option<u32>>
The index of the ledger that contains the transaction that most recently modified this entry.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".