pub trait CurrentAccountRootFields: CurrentLedgerObjectCommonFields {
Show 26 methods
// Provided methods
fn account(&self) -> Result<AccountID> { ... }
fn sequence(&self) -> Result<u32> { ... }
fn balance(&self) -> Result<Amount> { ... }
fn owner_count(&self) -> Result<u32> { ... }
fn previous_txn_id(&self) -> Result<Hash256> { ... }
fn previous_txn_lgr_seq(&self) -> Result<u32> { ... }
fn account_txn_id(&self) -> Result<Option<Hash256>> { ... }
fn regular_key(&self) -> Result<Option<AccountID>> { ... }
fn email_hash(&self) -> Result<Option<Hash128>> { ... }
fn wallet_locator(&self) -> Result<Option<Hash256>> { ... }
fn wallet_size(&self) -> Result<Option<u32>> { ... }
fn message_key(&self) -> Result<Option<PublicKeyBlob>> { ... }
fn transfer_rate(&self) -> Result<Option<u32>> { ... }
fn domain(&self) -> Result<Option<UriBlob>> { ... }
fn tick_size(&self) -> Result<Option<u8>> { ... }
fn ticket_count(&self) -> Result<Option<u32>> { ... }
fn nftoken_minter(&self) -> Result<Option<AccountID>> { ... }
fn minted_nftokens(&self) -> Result<Option<u32>> { ... }
fn burned_nftokens(&self) -> Result<Option<u32>> { ... }
fn first_nftoken_sequence(&self) -> Result<Option<u32>> { ... }
fn sponsored_owner_count(&self) -> Result<Option<u32>> { ... }
fn sponsoring_owner_count(&self) -> Result<Option<u32>> { ... }
fn sponsoring_account_count(&self) -> Result<Option<u32>> { ... }
fn amm_id(&self) -> Result<Option<Hash256>> { ... }
fn vault_id(&self) -> Result<Option<Hash256>> { ... }
fn loan_broker_id(&self) -> Result<Option<Hash256>> { ... }
}Expand description
Trait providing access to fields specific to the current AccountRoot object.
Provided Methods
Sourcefn sequence(&self) -> Result<u32>
fn sequence(&self) -> Result<u32>
The sequence number of the next valid transaction for this account.
Sourcefn balance(&self) -> Result<Amount>
fn balance(&self) -> Result<Amount>
The account’s current XRP balance in drops, represented as a string.
Sourcefn owner_count(&self) -> Result<u32>
fn owner_count(&self) -> Result<u32>
The number of objects this account owns in the ledger, which contributes to its owner reserve.
Sourcefn previous_txn_id(&self) -> Result<Hash256>
fn previous_txn_id(&self) -> Result<Hash256>
The identifying hash of the transaction that most recently modified this object.
Sourcefn previous_txn_lgr_seq(&self) -> Result<u32>
fn previous_txn_lgr_seq(&self) -> Result<u32>
The index of the ledger that contains the transaction that most recently modified this object.
Sourcefn account_txn_id(&self) -> Result<Option<Hash256>>
fn account_txn_id(&self) -> Result<Option<Hash256>>
The identifying hash of the transaction most recently sent by this account. This field must
be enabled to use the AccountTxnID transaction field. To enable it, send an AccountSet
transaction with the asfAccountTxnID flag enabled.
Sourcefn regular_key(&self) -> Result<Option<AccountID>>
fn regular_key(&self) -> Result<Option<AccountID>>
The address of a key pair that can be used to sign transactions for this account instead of the master key. Use a SetRegularKey transaction to change this value.
Sourcefn email_hash(&self) -> Result<Option<Hash128>>
fn email_hash(&self) -> Result<Option<Hash128>>
The md5 hash of an email address. Clients can use this to look up an avatar through services such as Gravatar.
Sourcefn wallet_locator(&self) -> Result<Option<Hash256>>
fn wallet_locator(&self) -> Result<Option<Hash256>>
An arbitrary 256-bit value that users can set.
Sourcefn wallet_size(&self) -> Result<Option<u32>>
fn wallet_size(&self) -> Result<Option<u32>>
Unused. (The code supports this field but there is no way to set it.)
Sourcefn message_key(&self) -> Result<Option<PublicKeyBlob>>
fn message_key(&self) -> Result<Option<PublicKeyBlob>>
A public key that may be used to send encrypted messages to this account. In JSON, uses
hexadecimal. Must be exactly 33 bytes, with the first byte indicating the key type: 0x02
or 0x03 for secp256k1 keys, 0xED for Ed25519 keys.
Sourcefn transfer_rate(&self) -> Result<Option<u32>>
fn transfer_rate(&self) -> Result<Option<u32>>
A transfer fee to charge other users for sending currency issued by this account to each other.
Sourcefn domain(&self) -> Result<Option<UriBlob>>
fn domain(&self) -> Result<Option<UriBlob>>
A domain associated with this account. In JSON, this is the hexadecimal for the ASCII representation of the domain. Cannot be more than 256 bytes in length.
Sourcefn tick_size(&self) -> Result<Option<u8>>
fn tick_size(&self) -> Result<Option<u8>>
How many significant digits to use for exchange rates of Offers involving currencies issued
by this address. Valid values are 3 to 15, inclusive.
Sourcefn ticket_count(&self) -> Result<Option<u32>>
fn ticket_count(&self) -> Result<Option<u32>>
How many Tickets this account owns in the ledger. This is updated automatically to ensure that the account stays within the hard limit of 250 Tickets at a time. This field is omitted if the account has zero Tickets.
Sourcefn nftoken_minter(&self) -> Result<Option<AccountID>>
fn nftoken_minter(&self) -> Result<Option<AccountID>>
Another account that can mint non-fungible tokens on behalf of this account.
Sourcefn minted_nftokens(&self) -> Result<Option<u32>>
fn minted_nftokens(&self) -> Result<Option<u32>>
How many total non-fungible tokens have been minted by and on behalf of this account.
Sourcefn burned_nftokens(&self) -> Result<Option<u32>>
fn burned_nftokens(&self) -> Result<Option<u32>>
How many total of this account’s issued non-fungible tokens have been burned. This number is
always equal or less than MintedNFTokens.
Sourcefn first_nftoken_sequence(&self) -> Result<Option<u32>>
fn first_nftoken_sequence(&self) -> Result<Option<u32>>
The account’s Sequence Number at the time it minted its first non-fungible-token.
Sourcefn sponsored_owner_count(&self) -> Result<Option<u32>>
fn sponsored_owner_count(&self) -> Result<Option<u32>>
The number of objects this account owns that are sponsored by another account.
Sourcefn sponsoring_owner_count(&self) -> Result<Option<u32>>
fn sponsoring_owner_count(&self) -> Result<Option<u32>>
The number of objects this account is sponsoring the reserve for.
Sourcefn sponsoring_account_count(&self) -> Result<Option<u32>>
fn sponsoring_account_count(&self) -> Result<Option<u32>>
The number of accounts this account is sponsoring the account reserve for.
Sourcefn amm_id(&self) -> Result<Option<Hash256>>
fn amm_id(&self) -> Result<Option<Hash256>>
If present, indicates that this is a special AMM pseudo-account AccountRoot; always omitted on non-AMM accounts. Contains the ledger entry ID of the corresponding AMM ledger entry. Set during account creation; cannot be modified.
Sourcefn vault_id(&self) -> Result<Option<Hash256>>
fn vault_id(&self) -> Result<Option<Hash256>>
The ID of the Vault entry associated with this account. Set during account creation;
cannot be modified. If present, indicates that this is a special Vault pseudo-account
AccountRoot; always omitted on non-Vault accounts.
Sourcefn loan_broker_id(&self) -> Result<Option<Hash256>>
fn loan_broker_id(&self) -> Result<Option<Hash256>>
The LoanBrokerID field (Optional).
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".