CurrentAmendmentsFields

Trait CurrentAmendmentsFields 

pub trait CurrentAmendmentsFields: CurrentLedgerObjectCommonFields {
    // Provided methods
    fn amendments(&self) -> Result<Option<[u8; 512]>> { ... }
    fn previous_txn_id(&self) -> Result<Option<Hash256>> { ... }
    fn previous_txn_lgr_seq(&self) -> Result<Option<u32>> { ... }
}
Trait providing access to fields specific to the current Amendments object.

Provided Methods

fn amendments(&self) -> Result<Option<[u8; 512]>>

Array of 256-bit amendment IDs for all currently enabled amendments. If omitted, there are no enabled amendments. Raw bytes; VECTOR256 is not yet typed in Rust.

fn previous_txn_id(&self) -> Result<Option<Hash256>>

The identifying hash of the transaction that most recently modified this entry.

fn previous_txn_lgr_seq(&self) -> Result<Option<u32>>

The index of the ledger that contains the transaction that most recently modified this entry.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors