CurrentCredentialFields

Trait CurrentCredentialFields 

pub trait CurrentCredentialFields: CurrentLedgerObjectCommonFields {
    // Provided methods
    fn subject(&self) -> Result<AccountID> { ... }
    fn issuer(&self) -> Result<AccountID> { ... }
    fn credential_type(&self) -> Result<StandardBlob> { ... }
    fn expiration(&self) -> Result<Option<u32>> { ... }
    fn uri(&self) -> Result<Option<UriBlob>> { ... }
    fn issuer_node(&self) -> Result<u64> { ... }
    fn subject_node(&self) -> Result<Option<u64>> { ... }
    fn previous_txn_id(&self) -> Result<Hash256> { ... }
    fn previous_txn_lgr_seq(&self) -> Result<u32> { ... }
}
Trait providing access to fields specific to the current Credential object.

Provided Methods

fn subject(&self) -> Result<AccountID>

The account that this credential is for.

fn issuer(&self) -> Result<AccountID>

The account that issued this credential.

fn credential_type(&self) -> Result<StandardBlob>

Arbitrary data defining the type of credential this entry represents. The minimum length is 1 byte and the maximum length is 64 bytes.

fn expiration(&self) -> Result<Option<u32>>

The Expiration field (Optional).

fn uri(&self) -> Result<Option<UriBlob>>

Arbitrary additional data about the credential, for example a URL where a W3C-formatted Verifiable Credential can be retrieved.

fn issuer_node(&self) -> Result<u64>

A hint indicating which page of the issuer’s directory links to this entry, in case the directory consists of multiple pages.

fn subject_node(&self) -> Result<Option<u64>>

A hint indicating which page of the subject’s owner directory links to this entry, in case the directory consists of multiple pages.

fn previous_txn_id(&self) -> Result<Hash256>

The identifying hash of the transaction that most recently modified this entry.

fn previous_txn_lgr_seq(&self) -> Result<u32>

The index of the ledger that contains the transaction that most recently modified this entry.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors