CurrentDIDFields

Trait CurrentDIDFields 

pub trait CurrentDIDFields: CurrentLedgerObjectCommonFields {
    // Provided methods
    fn account(&self) -> Result<AccountID> { ... }
    fn did_document(&self) -> Result<Option<StandardBlob>> { ... }
    fn uri(&self) -> Result<Option<UriBlob>> { ... }
    fn data(&self) -> Result<Option<StandardBlob>> { ... }
    fn owner_node(&self) -> Result<u64> { ... }
    fn previous_txn_id(&self) -> Result<Hash256> { ... }
    fn previous_txn_lgr_seq(&self) -> Result<u32> { ... }
}
Trait providing access to fields specific to the current DID object.

Provided Methods

fn account(&self) -> Result<AccountID>

The account that controls the DID.

fn did_document(&self) -> Result<Option<StandardBlob>>

The W3C standard DID document associated with the DID. The DIDDocument field isn’t checked for validity and is limited to a maximum length of 256 bytes.

fn uri(&self) -> Result<Option<UriBlob>>

The Universal Resource Identifier that points to the corresponding DID document or the data associated with the DID. This field can be an HTTP(S) URL or IPFS URI. This field isn’t checked for validity and is limited to a maximum length of 256 bytes.

fn data(&self) -> Result<Option<StandardBlob>>

The public attestations of identity credentials associated with the DID. The Data field isn’t checked for validity and is limited to a maximum length of 256 bytes.

fn owner_node(&self) -> Result<u64>

A hint indicating which page of the sender’s owner directory links to this entry, in case the directory consists of multiple pages.

fn previous_txn_id(&self) -> Result<Hash256>

The identifying hash of the transaction that most recently modified this object.

fn previous_txn_lgr_seq(&self) -> Result<u32>

The index of the ledger that contains the transaction that most recently modified this object.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors