pub trait CurrentDelegateFields: CurrentLedgerObjectCommonFields {
// Provided methods
fn account(&self) -> Result<AccountID> { ... }
fn authorize(&self) -> Result<AccountID> { ... }
fn owner_node(&self) -> Result<u64> { ... }
fn destination_node(&self) -> Result<Option<u64>> { ... }
fn previous_txn_id(&self) -> Result<Hash256> { ... }
fn previous_txn_lgr_seq(&self) -> Result<u32> { ... }
}Expand description
Trait providing access to fields specific to the current Delegate object.
Provided Methods
Sourcefn account(&self) -> Result<AccountID>
fn account(&self) -> Result<AccountID>
The account delegating permissions to another, also called the delegating account.
The account receiving permissions, also called the delegate.
Sourcefn owner_node(&self) -> Result<u64>
fn owner_node(&self) -> Result<u64>
A hint indicating which page of the delegating account’s owner directory links to this object, in case the directory consists of multiple pages.
Sourcefn destination_node(&self) -> Result<Option<u64>>
fn destination_node(&self) -> Result<Option<u64>>
A hint indicating which page of the delegate’s owner directory links to this object, in case the directory consists of multiple pages.
Sourcefn previous_txn_id(&self) -> Result<Hash256>
fn previous_txn_id(&self) -> Result<Hash256>
The identifying hash of the transaction that most recently modified this object.
Sourcefn previous_txn_lgr_seq(&self) -> Result<u32>
fn previous_txn_lgr_seq(&self) -> Result<u32>
The index of the ledger that contains the transaction that most recently modified this object.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".