pub trait CurrentDirectoryNodeFields: CurrentLedgerObjectCommonFields {
Show 16 methods
// Provided methods
fn owner(&self) -> Result<Option<AccountID>> { ... }
fn taker_pays_currency(&self) -> Result<Option<Hash160>> { ... }
fn taker_pays_issuer(&self) -> Result<Option<Hash160>> { ... }
fn taker_pays_mpt(&self) -> Result<Option<Hash192>> { ... }
fn taker_gets_currency(&self) -> Result<Option<Hash160>> { ... }
fn taker_gets_issuer(&self) -> Result<Option<Hash160>> { ... }
fn taker_gets_mpt(&self) -> Result<Option<Hash192>> { ... }
fn exchange_rate(&self) -> Result<Option<u64>> { ... }
fn indexes(&self) -> Result<[u8; 512]> { ... }
fn root_index(&self) -> Result<Hash256> { ... }
fn index_next(&self) -> Result<Option<u64>> { ... }
fn index_previous(&self) -> Result<Option<u64>> { ... }
fn nftoken_id(&self) -> Result<Option<Hash256>> { ... }
fn previous_txn_id(&self) -> Result<Option<Hash256>> { ... }
fn previous_txn_lgr_seq(&self) -> Result<Option<u32>> { ... }
fn domain_id(&self) -> Result<Option<Hash256>> { ... }
}Expand description
Trait providing access to fields specific to the current DirectoryNode object.
Provided Methods
Sourcefn owner(&self) -> Result<Option<AccountID>>
fn owner(&self) -> Result<Option<AccountID>>
(Owner directories only) The address of the account that owns the objects in this directory.
Sourcefn taker_pays_currency(&self) -> Result<Option<Hash160>>
fn taker_pays_currency(&self) -> Result<Option<Hash160>>
(Offer directories only) The currency code of the TakerPays amount from the offers in this
directory.
Sourcefn taker_pays_issuer(&self) -> Result<Option<Hash160>>
fn taker_pays_issuer(&self) -> Result<Option<Hash160>>
(Offer directories only) The issuer of the TakerPays amount from the offers in this
directory.
Sourcefn taker_pays_mpt(&self) -> Result<Option<Hash192>>
fn taker_pays_mpt(&self) -> Result<Option<Hash192>>
The TakerPaysMPT field (Optional).
Sourcefn taker_gets_currency(&self) -> Result<Option<Hash160>>
fn taker_gets_currency(&self) -> Result<Option<Hash160>>
(Offer directories only) The currency code of the TakerGets amount from the offers in this
directory.
Sourcefn taker_gets_issuer(&self) -> Result<Option<Hash160>>
fn taker_gets_issuer(&self) -> Result<Option<Hash160>>
(Offer directories only) The issuer of the TakerGets amount from the offers in this
directory.
Sourcefn taker_gets_mpt(&self) -> Result<Option<Hash192>>
fn taker_gets_mpt(&self) -> Result<Option<Hash192>>
The TakerGetsMPT field (Optional).
Sourcefn exchange_rate(&self) -> Result<Option<u64>>
fn exchange_rate(&self) -> Result<Option<u64>>
(Offer directories only) DEPRECATED. Do not use.
Sourcefn indexes(&self) -> Result<[u8; 512]>
fn indexes(&self) -> Result<[u8; 512]>
The contents of this directory: an array of IDs of other objects. Raw bytes; VECTOR256 is not yet typed in Rust.
Sourcefn root_index(&self) -> Result<Hash256>
fn root_index(&self) -> Result<Hash256>
The ID of root object for this directory.
Sourcefn index_next(&self) -> Result<Option<u64>>
fn index_next(&self) -> Result<Option<u64>>
If this directory consists of multiple pages, this ID links to the next object in the chain, wrapping around at the end.
Sourcefn index_previous(&self) -> Result<Option<u64>>
fn index_previous(&self) -> Result<Option<u64>>
If this directory consists of multiple pages, this ID links to the previous object in the chain, wrapping around at the beginning.
Sourcefn nftoken_id(&self) -> Result<Option<Hash256>>
fn nftoken_id(&self) -> Result<Option<Hash256>>
(NFT offer directories only) ID of the NFT in a buy or sell offer.
Sourcefn previous_txn_id(&self) -> Result<Option<Hash256>>
fn previous_txn_id(&self) -> Result<Option<Hash256>>
The identifying hash of the transaction that most recently modified this entry.
Sourcefn previous_txn_lgr_seq(&self) -> Result<Option<u32>>
fn previous_txn_lgr_seq(&self) -> Result<Option<u32>>
The index of the ledger that contains the transaction that most recently modified this entry.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".