pub trait CurrentMPTokenFields: CurrentLedgerObjectCommonFields {
Show 13 methods
// Provided methods
fn account(&self) -> Result<AccountID> { ... }
fn mptoken_issuance_id(&self) -> Result<Hash192> { ... }
fn mpt_amount(&self) -> Result<Option<u64>> { ... }
fn locked_amount(&self) -> Result<Option<u64>> { ... }
fn owner_node(&self) -> Result<u64> { ... }
fn previous_txn_id(&self) -> Result<Hash256> { ... }
fn previous_txn_lgr_seq(&self) -> Result<u32> { ... }
fn confidential_balance_inbox(&self) -> Result<Option<StandardBlob>> { ... }
fn confidential_balance_spending(&self) -> Result<Option<StandardBlob>> { ... }
fn confidential_balance_version(&self) -> Result<Option<u32>> { ... }
fn issuer_encrypted_balance(&self) -> Result<Option<StandardBlob>> { ... }
fn auditor_encrypted_balance(&self) -> Result<Option<StandardBlob>> { ... }
fn holder_encryption_key(&self) -> Result<Option<StandardBlob>> { ... }
}Expand description
Trait providing access to fields specific to the current MPToken object.
Provided Methods
Sourcefn mptoken_issuance_id(&self) -> Result<Hash192>
fn mptoken_issuance_id(&self) -> Result<Hash192>
The MPTokenIssuance identifier.
Sourcefn mpt_amount(&self) -> Result<Option<u64>>
fn mpt_amount(&self) -> Result<Option<u64>>
The amount of tokens currently held by the owner. The minimum is 0 and the maximum is 2^63-1.
Sourcefn locked_amount(&self) -> Result<Option<u64>>
fn locked_amount(&self) -> Result<Option<u64>>
The amount of tokens currently locked up (for example, in escrow).
Sourcefn owner_node(&self) -> Result<u64>
fn owner_node(&self) -> Result<u64>
A hint indicating which page of the owner directory links to this entry, in case the directory consists of multiple pages.
Sourcefn previous_txn_id(&self) -> Result<Hash256>
fn previous_txn_id(&self) -> Result<Hash256>
The identifying hash of the transaction that most recently modified this entry.
Sourcefn previous_txn_lgr_seq(&self) -> Result<u32>
fn previous_txn_lgr_seq(&self) -> Result<u32>
The sequence of the ledger that contains the transaction that most recently modified this object.
Sourcefn confidential_balance_inbox(&self) -> Result<Option<StandardBlob>>
fn confidential_balance_inbox(&self) -> Result<Option<StandardBlob>>
Encrypted inbox balance that receives incoming confidential transfers. Before it can be spent, the holder must merge it into their spending balance using the ConfidentialMPTMergeInbox transaction. Present when the holder has a confidential balance.
Sourcefn confidential_balance_spending(&self) -> Result<Option<StandardBlob>>
fn confidential_balance_spending(&self) -> Result<Option<StandardBlob>>
Encrypted spending balance used to generate proofs for outgoing transactions. Present when the holder has a confidential balance.
Sourcefn confidential_balance_version(&self) -> Result<Option<u32>>
fn confidential_balance_version(&self) -> Result<Option<u32>>
Version number that increments each time the spending balance changes. This version is cryptographically bound to ZKPs in outgoing transactions to prevent replay attacks and ensure proof validity. If the version changes between proof generation and submission, the transaction will fail.
Sourcefn issuer_encrypted_balance(&self) -> Result<Option<StandardBlob>>
fn issuer_encrypted_balance(&self) -> Result<Option<StandardBlob>>
Copy of the holder’s total confidential balance encrypted for the issuer to audit supply. Present when the holder has a confidential balance.
Sourcefn auditor_encrypted_balance(&self) -> Result<Option<StandardBlob>>
fn auditor_encrypted_balance(&self) -> Result<Option<StandardBlob>>
The holder’s total confidential balance encrypted under the auditor’s key for independent auditing. Only present if an auditor is configured.
Sourcefn holder_encryption_key(&self) -> Result<Option<StandardBlob>>
fn holder_encryption_key(&self) -> Result<Option<StandardBlob>>
The holder’s ElGamal public key for confidential balances. Present when the holder has a confidential balance.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".