CurrentNFTokenPageFields

Trait CurrentNFTokenPageFields 

pub trait CurrentNFTokenPageFields: CurrentLedgerObjectCommonFields {
    // Provided methods
    fn previous_page_min(&self) -> Result<Option<Hash256>> { ... }
    fn next_page_min(&self) -> Result<Option<Hash256>> { ... }
    fn previous_txn_id(&self) -> Result<Hash256> { ... }
    fn previous_txn_lgr_seq(&self) -> Result<u32> { ... }
}
Trait providing access to fields specific to the current NFTokenPage object.

Provided Methods

fn previous_page_min(&self) -> Result<Option<Hash256>>

The locator of the previous page, if any. Details about this field and how it should be used are outlined below.

fn next_page_min(&self) -> Result<Option<Hash256>>

The locator of the next page, if any. Details about this field and how it should be used are outlined below.

fn previous_txn_id(&self) -> Result<Hash256>

Identifies the transaction ID of the transaction that most recently modified this NFTokenPage object.

fn previous_txn_lgr_seq(&self) -> Result<u32>

The sequence of the ledger that contains the transaction that most recently modified this NFTokenPage object.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors