CurrentNegativeUNLFields

Trait CurrentNegativeUNLFields 

pub trait CurrentNegativeUNLFields: CurrentLedgerObjectCommonFields {
    // Provided methods
    fn validator_to_disable(&self) -> Result<Option<StandardBlob>> { ... }
    fn validator_to_re_enable(&self) -> Result<Option<StandardBlob>> { ... }
    fn previous_txn_id(&self) -> Result<Option<Hash256>> { ... }
    fn previous_txn_lgr_seq(&self) -> Result<Option<u32>> { ... }
}
Trait providing access to fields specific to the current NegativeUNL object.

Provided Methods

fn validator_to_disable(&self) -> Result<Option<StandardBlob>>

The public key of a trusted validator that is scheduled to be disabled in the next flag ledger.

fn validator_to_re_enable(&self) -> Result<Option<StandardBlob>>

The public key of a trusted validator in the Negative UNL that is scheduled to be re-enabled in the next flag ledger.

fn previous_txn_id(&self) -> Result<Option<Hash256>>

The identifying hash of the transaction that most recently modified this entry.

fn previous_txn_lgr_seq(&self) -> Result<Option<u32>>

The index of the ledger that contains the transaction that most recently modified this entry.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors