CurrentOfferFields

Trait CurrentOfferFields 

pub trait CurrentOfferFields: CurrentLedgerObjectCommonFields {
    // Provided methods
    fn account(&self) -> Result<AccountID> { ... }
    fn sequence(&self) -> Result<u32> { ... }
    fn taker_pays(&self) -> Result<Amount> { ... }
    fn taker_gets(&self) -> Result<Amount> { ... }
    fn book_directory(&self) -> Result<Hash256> { ... }
    fn book_node(&self) -> Result<u64> { ... }
    fn owner_node(&self) -> Result<u64> { ... }
    fn previous_txn_id(&self) -> Result<Hash256> { ... }
    fn previous_txn_lgr_seq(&self) -> Result<u32> { ... }
    fn expiration(&self) -> Result<Option<u32>> { ... }
    fn domain_id(&self) -> Result<Option<Hash256>> { ... }
}
Trait providing access to fields specific to the current Offer object.

Provided Methods

fn account(&self) -> Result<AccountID>

The account that owns this offer.

fn sequence(&self) -> Result<u32>

The Sequence value of the OfferCreate transaction that created this offer. Used in combination with the Account to identify this offer.

fn taker_pays(&self) -> Result<Amount>

The remaining amount and type of currency requested by the offer creator.

fn taker_gets(&self) -> Result<Amount>

The remaining amount and type of currency being provided by the offer creator.

fn book_directory(&self) -> Result<Hash256>

The ID of the offer directory that links to this offer.

fn book_node(&self) -> Result<u64>

A hint indicating which page of the offer directory links to this entry, in case the directory consists of multiple pages.

fn owner_node(&self) -> Result<u64>

A hint indicating which page of the owner directory links to this entry, in case the directory consists of multiple pages.

fn previous_txn_id(&self) -> Result<Hash256>

The identifying hash of the transaction that most recently modified this entry.

fn previous_txn_lgr_seq(&self) -> Result<u32>

The index of the ledger that contains the transaction that most recently modified this object.

fn expiration(&self) -> Result<Option<u32>>

Indicates the time after which this offer is considered unfunded. See Specifying Time for details.

fn domain_id(&self) -> Result<Option<Hash256>>

The ledger entry ID of a permissioned domain. If present, this offer belongs to the corresponding Permissioned DEX.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors