CurrentPermissionedDomainFields

Trait CurrentPermissionedDomainFields 

pub trait CurrentPermissionedDomainFields: CurrentLedgerObjectCommonFields {
    // Provided methods
    fn owner(&self) -> Result<AccountID> { ... }
    fn sequence(&self) -> Result<u32> { ... }
    fn owner_node(&self) -> Result<u64> { ... }
    fn previous_txn_id(&self) -> Result<Hash256> { ... }
    fn previous_txn_lgr_seq(&self) -> Result<u32> { ... }
}
Trait providing access to fields specific to the current PermissionedDomain object.

Provided Methods

fn owner(&self) -> Result<AccountID>

The address of the account that owns this domain.

fn sequence(&self) -> Result<u32>

The Sequence value of the transaction that created this entry.

fn owner_node(&self) -> Result<u64>

A hint indicating which page of the owner directory links to this entry, in case the directory consists of multiple pages.

fn previous_txn_id(&self) -> Result<Hash256>

The identifying hash of the transaction that most recently modified this entry.

fn previous_txn_lgr_seq(&self) -> Result<u32>

The index of the ledger that contains the transaction that most recently modified this object.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors