CurrentSignerListFields

Trait CurrentSignerListFields 

pub trait CurrentSignerListFields: CurrentLedgerObjectCommonFields {
    // Provided methods
    fn owner(&self) -> Result<Option<AccountID>> { ... }
    fn owner_node(&self) -> Result<u64> { ... }
    fn signer_quorum(&self) -> Result<u32> { ... }
    fn signer_list_id(&self) -> Result<u32> { ... }
    fn previous_txn_id(&self) -> Result<Hash256> { ... }
    fn previous_txn_lgr_seq(&self) -> Result<u32> { ... }
}
Trait providing access to fields specific to the current SignerList object.

Provided Methods

fn owner(&self) -> Result<Option<AccountID>>

The Owner field (Optional).

fn owner_node(&self) -> Result<u64>

A hint indicating which page of the owner directory links to this object, in case the directory consists of multiple pages.

fn signer_quorum(&self) -> Result<u32>

A target number for signer weights. To produce a valid signature for the owner of this SignerList, the signers must provide valid signatures whose weights sum to this value or more.

fn signer_list_id(&self) -> Result<u32>

An ID for this signer list. Currently always set to 0. If a future amendment allows multiple signer lists for an account, this may change.

fn previous_txn_id(&self) -> Result<Hash256>

The identifying hash of the transaction that most recently modified this object.

fn previous_txn_lgr_seq(&self) -> Result<u32>

The index of the ledger that contains the transaction that most recently modified this object.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors