CurrentXChainOwnedClaimIDFields

Trait CurrentXChainOwnedClaimIDFields 

pub trait CurrentXChainOwnedClaimIDFields: CurrentLedgerObjectCommonFields {
    // Provided methods
    fn account(&self) -> Result<AccountID> { ... }
    fn xchain_bridge(&self) -> Result<[u8; 512]> { ... }
    fn xchain_claim_id(&self) -> Result<u64> { ... }
    fn other_chain_source(&self) -> Result<AccountID> { ... }
    fn signature_reward(&self) -> Result<Amount> { ... }
    fn owner_node(&self) -> Result<u64> { ... }
    fn previous_txn_id(&self) -> Result<Hash256> { ... }
    fn previous_txn_lgr_seq(&self) -> Result<u32> { ... }
}
Trait providing access to fields specific to the current XChainOwnedClaimID object.

Provided Methods

fn account(&self) -> Result<AccountID>

The account that owns this object.

fn xchain_bridge(&self) -> Result<[u8; 512]>

The door accounts and assets of the bridge this object correlates to. Raw bytes; XCHAIN_BRIDGE is not yet typed in Rust.

fn xchain_claim_id(&self) -> Result<u64>

The unique sequence number for a cross-chain transfer.

fn other_chain_source(&self) -> Result<AccountID>

The account that must send the corresponding XChainCommit on the source chain. The destination may be specified in the XChainCommit transaction, which means that if the OtherChainSource isn’t specified, another account can try to specify a different destination and steal the funds. This also allows tracking only a single set of signatures, since we know which account will send the XChainCommit transaction.

fn signature_reward(&self) -> Result<Amount>

The total amount to pay the witness servers for their signatures. It must be at least the value of SignatureReward in the Bridge ledger object.

fn owner_node(&self) -> Result<u64>

The OwnerNode field (Required).

fn previous_txn_id(&self) -> Result<Hash256>

The PreviousTxnID field (Required).

fn previous_txn_lgr_seq(&self) -> Result<u32>

The PreviousTxnLgrSeq field (Required).

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors