DelegateFields

Trait DelegateFields 

pub trait DelegateFields: LedgerObjectCommonFields {
    // Provided methods
    fn account(&self) -> Result<AccountID> { ... }
    fn authorize(&self) -> Result<AccountID> { ... }
    fn owner_node(&self) -> Result<u64> { ... }
    fn destination_node(&self) -> Result<Option<u64>> { ... }
    fn previous_txn_id(&self) -> Result<Hash256> { ... }
    fn previous_txn_lgr_seq(&self) -> Result<u32> { ... }
}
Trait providing access to fields specific to Delegate objects in any ledger.

Provided Methods

fn account(&self) -> Result<AccountID>

The account delegating permissions to another, also called the delegating account.

fn authorize(&self) -> Result<AccountID>

The account receiving permissions, also called the delegate.

fn owner_node(&self) -> Result<u64>

A hint indicating which page of the delegating account’s owner directory links to this object, in case the directory consists of multiple pages.

fn destination_node(&self) -> Result<Option<u64>>

A hint indicating which page of the delegate’s owner directory links to this object, in case the directory consists of multiple pages.

fn previous_txn_id(&self) -> Result<Hash256>

The identifying hash of the transaction that most recently modified this object.

fn previous_txn_lgr_seq(&self) -> Result<u32>

The index of the ledger that contains the transaction that most recently modified this object.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors