DirectoryNodeFields

Trait DirectoryNodeFields 

pub trait DirectoryNodeFields: LedgerObjectCommonFields {
Show 16 methods // Provided methods fn owner(&self) -> Result<Option<AccountID>> { ... } fn taker_pays_currency(&self) -> Result<Option<Hash160>> { ... } fn taker_pays_issuer(&self) -> Result<Option<Hash160>> { ... } fn taker_pays_mpt(&self) -> Result<Option<Hash192>> { ... } fn taker_gets_currency(&self) -> Result<Option<Hash160>> { ... } fn taker_gets_issuer(&self) -> Result<Option<Hash160>> { ... } fn taker_gets_mpt(&self) -> Result<Option<Hash192>> { ... } fn exchange_rate(&self) -> Result<Option<u64>> { ... } fn indexes(&self) -> Result<[u8; 512]> { ... } fn root_index(&self) -> Result<Hash256> { ... } fn index_next(&self) -> Result<Option<u64>> { ... } fn index_previous(&self) -> Result<Option<u64>> { ... } fn nftoken_id(&self) -> Result<Option<Hash256>> { ... } fn previous_txn_id(&self) -> Result<Option<Hash256>> { ... } fn previous_txn_lgr_seq(&self) -> Result<Option<u32>> { ... } fn domain_id(&self) -> Result<Option<Hash256>> { ... }
}
Trait providing access to fields specific to DirectoryNode objects in any ledger.

Provided Methods

fn owner(&self) -> Result<Option<AccountID>>

(Owner directories only) The address of the account that owns the objects in this directory.

fn taker_pays_currency(&self) -> Result<Option<Hash160>>

(Offer directories only) The currency code of the TakerPays amount from the offers in this directory.

fn taker_pays_issuer(&self) -> Result<Option<Hash160>>

(Offer directories only) The issuer of the TakerPays amount from the offers in this directory.

fn taker_pays_mpt(&self) -> Result<Option<Hash192>>

The TakerPaysMPT field (Optional).

fn taker_gets_currency(&self) -> Result<Option<Hash160>>

(Offer directories only) The currency code of the TakerGets amount from the offers in this directory.

fn taker_gets_issuer(&self) -> Result<Option<Hash160>>

(Offer directories only) The issuer of the TakerGets amount from the offers in this directory.

fn taker_gets_mpt(&self) -> Result<Option<Hash192>>

The TakerGetsMPT field (Optional).

fn exchange_rate(&self) -> Result<Option<u64>>

(Offer directories only) DEPRECATED. Do not use.

fn indexes(&self) -> Result<[u8; 512]>

The contents of this directory: an array of IDs of other objects. Raw bytes; VECTOR256 is not yet typed in Rust.

fn root_index(&self) -> Result<Hash256>

The ID of root object for this directory.

fn index_next(&self) -> Result<Option<u64>>

If this directory consists of multiple pages, this ID links to the next object in the chain, wrapping around at the end.

fn index_previous(&self) -> Result<Option<u64>>

If this directory consists of multiple pages, this ID links to the previous object in the chain, wrapping around at the beginning.

fn nftoken_id(&self) -> Result<Option<Hash256>>

(NFT offer directories only) ID of the NFT in a buy or sell offer.

fn previous_txn_id(&self) -> Result<Option<Hash256>>

The identifying hash of the transaction that most recently modified this entry.

fn previous_txn_lgr_seq(&self) -> Result<Option<u32>>

The index of the ledger that contains the transaction that most recently modified this entry.

fn domain_id(&self) -> Result<Option<Hash256>>

(Offer directories only) The ledger entry ID of a permissioned domain. If present, this order book belongs to the corresponding Permissioned DEX. Otherwise, this order book is part of the open DEX.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors