FeeSettingsFields

Trait FeeSettingsFields 

pub trait FeeSettingsFields: LedgerObjectCommonFields {
    // Provided methods
    fn base_fee(&self) -> Result<Option<u64>> { ... }
    fn reference_fee_units(&self) -> Result<Option<u32>> { ... }
    fn reserve_base(&self) -> Result<Option<u32>> { ... }
    fn reserve_increment(&self) -> Result<Option<u32>> { ... }
    fn base_fee_drops(&self) -> Result<Option<Amount>> { ... }
    fn reserve_base_drops(&self) -> Result<Option<Amount>> { ... }
    fn reserve_increment_drops(&self) -> Result<Option<Amount>> { ... }
    fn gas_limit(&self) -> Result<Option<u32>> { ... }
    fn bytecode_size_limit(&self) -> Result<Option<u32>> { ... }
    fn gas_price(&self) -> Result<Option<u32>> { ... }
    fn previous_txn_id(&self) -> Result<Option<Hash256>> { ... }
    fn previous_txn_lgr_seq(&self) -> Result<Option<u32>> { ... }
}
Trait providing access to fields specific to FeeSettings objects in any ledger.

Provided Methods

fn base_fee(&self) -> Result<Option<u64>>

The transaction cost of the “reference transaction” in drops of XRP as hexadecimal.

fn reference_fee_units(&self) -> Result<Option<u32>>

The BaseFee translated into “fee units”.

fn reserve_base(&self) -> Result<Option<u32>>

The base reserve for an account in the XRP Ledger, as drops of XRP.

fn reserve_increment(&self) -> Result<Option<u32>>

The incremental owner reserve for owning objects, as drops of XRP.

fn base_fee_drops(&self) -> Result<Option<Amount>>

The transaction cost of the “reference transaction” in drops of XRP.

fn reserve_base_drops(&self) -> Result<Option<Amount>>

The base reserve for an account in the XRP Ledger, as drops of XRP.

fn reserve_increment_drops(&self) -> Result<Option<Amount>>

The incremental owner reserve for owning objects, as drops of XRP.

fn gas_limit(&self) -> Result<Option<u32>>

The GasLimit field (Optional).

fn bytecode_size_limit(&self) -> Result<Option<u32>>

The BytecodeSizeLimit field (Optional).

fn gas_price(&self) -> Result<Option<u32>>

The GasPrice field (Optional).

fn previous_txn_id(&self) -> Result<Option<Hash256>>

The identifying hash of the transaction that most recently modified this entry.

fn previous_txn_lgr_seq(&self) -> Result<Option<u32>>

The index of the ledger that contains the transaction that most recently modified this entry.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors