pub trait SponsorshipFields: LedgerObjectCommonFields {
// Provided methods
fn previous_txn_id(&self) -> Result<Hash256> { ... }
fn previous_txn_lgr_seq(&self) -> Result<u32> { ... }
fn owner(&self) -> Result<AccountID> { ... }
fn sponsee(&self) -> Result<AccountID> { ... }
fn fee_amount(&self) -> Result<Option<Amount>> { ... }
fn max_fee(&self) -> Result<Option<Amount>> { ... }
fn remaining_owner_count(&self) -> Result<Option<u32>> { ... }
fn owner_node(&self) -> Result<u64> { ... }
fn sponsee_node(&self) -> Result<u64> { ... }
}Expand description
Trait providing access to fields specific to Sponsorship objects in any ledger.
Provided Methods
Sourcefn previous_txn_id(&self) -> Result<Hash256>
fn previous_txn_id(&self) -> Result<Hash256>
The identifying hash of the transaction that most recently modified this entry.
Sourcefn previous_txn_lgr_seq(&self) -> Result<u32>
fn previous_txn_lgr_seq(&self) -> Result<u32>
The ledger index of the ledger that contains the transaction that most recently modified this entry.
Sourcefn owner(&self) -> Result<AccountID>
fn owner(&self) -> Result<AccountID>
The address of the sponsor account. This account pays the reserve for this entry.
Sourcefn sponsee(&self) -> Result<AccountID>
fn sponsee(&self) -> Result<AccountID>
The address of the sponsee account associated with this relationship.
Sourcefn fee_amount(&self) -> Result<Option<Amount>>
fn fee_amount(&self) -> Result<Option<Amount>>
The remaining amount of XRP that the sponsor has provided for the sponsee to use for
transaction fees. The sponsor adjusts this amount using the FeeAmountDelta field of a
SponsorshipSet transaction.
Sourcefn max_fee(&self) -> Result<Option<Amount>>
fn max_fee(&self) -> Result<Option<Amount>>
The maximum fee per transaction that the sponsor will cover. This field helps prevent excessive draining of the pre-funded fee pool. If the sponsee submits a transaction with a fee exceeding this value, the transaction fails.
Sourcefn remaining_owner_count(&self) -> Result<Option<u32>>
fn remaining_owner_count(&self) -> Result<Option<u32>>
The remaining number of owner reserves the sponsor has pre-funded for the sponsee. The
sponsor adjusts this count using the RemainingOwnerCountDelta field of a SponsorshipSet
transaction.
Sourcefn owner_node(&self) -> Result<u64>
fn owner_node(&self) -> Result<u64>
A hint indicating which page of the sponsor’s owner directory links to this entry, in case the directory consists of multiple pages.
Sourcefn sponsee_node(&self) -> Result<u64>
fn sponsee_node(&self) -> Result<u64>
A hint indicating which page of the sponsee’s owner directory links to this entry, in case the directory consists of multiple pages.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".