TicketFields

Trait TicketFields 

pub trait TicketFields: LedgerObjectCommonFields {
    // Provided methods
    fn account(&self) -> Result<AccountID> { ... }
    fn owner_node(&self) -> Result<u64> { ... }
    fn ticket_sequence(&self) -> Result<u32> { ... }
    fn previous_txn_id(&self) -> Result<Hash256> { ... }
    fn previous_txn_lgr_seq(&self) -> Result<u32> { ... }
}
Trait providing access to fields specific to Ticket objects in any ledger.

Provided Methods

fn account(&self) -> Result<AccountID>

The account that owns this Ticket.

fn owner_node(&self) -> Result<u64>

A hint indicating which page of the owner directory links to this entry, in case the directory consists of multiple pages.

fn ticket_sequence(&self) -> Result<u32>

The Sequence Number this Ticket sets aside.

fn previous_txn_id(&self) -> Result<Hash256>

The identifying hash of the transaction that most recently modified this entry.

fn previous_txn_lgr_seq(&self) -> Result<u32>

The index of the ledger that contains the transaction that most recently modified this entry.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors