pub trait CurrentCheckFields: CurrentLedgerObjectCommonFields {
// Provided methods
fn account(&self) -> Result<AccountID> { ... }
fn destination(&self) -> Result<AccountID> { ... }
fn send_max(&self) -> Result<Amount> { ... }
fn sequence(&self) -> Result<u32> { ... }
fn owner_node(&self) -> Result<u64> { ... }
fn destination_node(&self) -> Result<u64> { ... }
fn expiration(&self) -> Result<Option<u32>> { ... }
fn invoice_id(&self) -> Result<Option<Hash256>> { ... }
fn source_tag(&self) -> Result<Option<u32>> { ... }
fn destination_tag(&self) -> Result<Option<u32>> { ... }
fn previous_txn_id(&self) -> Result<Hash256> { ... }
fn previous_txn_lgr_seq(&self) -> Result<u32> { ... }
}Expand description
Trait providing access to fields specific to the current Check object.
Provided Methods
Sourcefn account(&self) -> Result<AccountID>
fn account(&self) -> Result<AccountID>
The sender of the Check. Cashing the Check debits this address’s balance.
Sourcefn destination(&self) -> Result<AccountID>
fn destination(&self) -> Result<AccountID>
The intended recipient of the Check. Only this address can cash the Check, using a CheckCash transaction.
Sourcefn send_max(&self) -> Result<Amount>
fn send_max(&self) -> Result<Amount>
The maximum amount of currency this Check can debit the sender. If the Check is successfully cashed, the destination is credited in the same currency for up to this amount.
Sourcefn sequence(&self) -> Result<u32>
fn sequence(&self) -> Result<u32>
The sequence number of the CheckCreate transaction that created this check.
Sourcefn owner_node(&self) -> Result<u64>
fn owner_node(&self) -> Result<u64>
A hint indicating which page of the sender’s owner directory links to this object, in case the directory consists of multiple pages.
Sourcefn destination_node(&self) -> Result<u64>
fn destination_node(&self) -> Result<u64>
A hint indicating which page of the destination’s owner directory links to this object, in case the directory consists of multiple pages.
Sourcefn expiration(&self) -> Result<Option<u32>>
fn expiration(&self) -> Result<Option<u32>>
Indicates the time after which this Check is considered expired. See Specifying Time for details.
Sourcefn invoice_id(&self) -> Result<Option<Hash256>>
fn invoice_id(&self) -> Result<Option<Hash256>>
Arbitrary 256-bit hash provided by the sender as a specific reason or identifier for this Check.
Sourcefn source_tag(&self) -> Result<Option<u32>>
fn source_tag(&self) -> Result<Option<u32>>
An arbitrary tag to further specify the source for this Check, such as a hosted recipient at the sender’s address.
Sourcefn destination_tag(&self) -> Result<Option<u32>>
fn destination_tag(&self) -> Result<Option<u32>>
An arbitrary tag to further specify the destination for this Check, such as a hosted recipient at the destination address.
Sourcefn previous_txn_id(&self) -> Result<Hash256>
fn previous_txn_id(&self) -> Result<Hash256>
The identifying hash of the transaction that most recently modified this object.
Sourcefn previous_txn_lgr_seq(&self) -> Result<u32>
fn previous_txn_lgr_seq(&self) -> Result<u32>
The index of the ledger that contains the transaction that most recently modified this object.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".