pub trait CurrentLedgerHashesFields: CurrentLedgerObjectCommonFields {
// Provided methods
fn first_ledger_sequence(&self) -> Result<Option<u32>> { ... }
fn last_ledger_sequence(&self) -> Result<Option<u32>> { ... }
fn hashes(&self) -> Result<[u8; 512]> { ... }
}Expand description
Trait providing access to fields specific to the current LedgerHashes object.
Provided Methods
Sourcefn first_ledger_sequence(&self) -> Result<Option<u32>>
fn first_ledger_sequence(&self) -> Result<Option<u32>>
DEPRECATED Do not use. (The “recent hashes” object on Mainnet has the value 2 in this
field as a result of an old software bug. That value gets carried forward as the “recent
hashes” object is updated. New “previous history” objects do not have this field, nor do
“recent hashes” objects in parallel networks started with more recent versions of xrpld.)
Sourcefn last_ledger_sequence(&self) -> Result<Option<u32>>
fn last_ledger_sequence(&self) -> Result<Option<u32>>
The Ledger Index of the last entry in this object’s Hashes array.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".