pub trait CurrentLoanBrokerFields: CurrentLedgerObjectCommonFields {
Show 17 methods
// Provided methods
fn previous_txn_id(&self) -> Result<Hash256> { ... }
fn previous_txn_lgr_seq(&self) -> Result<u32> { ... }
fn sequence(&self) -> Result<u32> { ... }
fn owner_node(&self) -> Result<u64> { ... }
fn vault_node(&self) -> Result<u64> { ... }
fn vault_id(&self) -> Result<Hash256> { ... }
fn account(&self) -> Result<AccountID> { ... }
fn owner(&self) -> Result<AccountID> { ... }
fn loan_sequence(&self) -> Result<u32> { ... }
fn data(&self) -> Result<Option<StandardBlob>> { ... }
fn management_fee_rate(&self) -> Result<Option<u16>> { ... }
fn owner_count(&self) -> Result<Option<u32>> { ... }
fn debt_total(&self) -> Result<Option<Number>> { ... }
fn debt_maximum(&self) -> Result<Option<Number>> { ... }
fn cover_available(&self) -> Result<Option<Number>> { ... }
fn cover_rate_minimum(&self) -> Result<Option<u32>> { ... }
fn cover_rate_liquidation(&self) -> Result<Option<u32>> { ... }
}Expand description
Trait providing access to fields specific to the current LoanBroker object.
Provided Methods
Sourcefn previous_txn_id(&self) -> Result<Hash256>
fn previous_txn_id(&self) -> Result<Hash256>
Identifies the transaction ID that most recently modified this object.
Sourcefn previous_txn_lgr_seq(&self) -> Result<u32>
fn previous_txn_lgr_seq(&self) -> Result<u32>
The sequence of the ledger that contains the transaction that most recently modified this object.
Sourcefn owner_node(&self) -> Result<u64>
fn owner_node(&self) -> Result<u64>
Identifies the page where this item is referenced in the owner’s directory.
Sourcefn vault_node(&self) -> Result<u64>
fn vault_node(&self) -> Result<u64>
Identifies the page where this item is referenced in the Vault pseudo-account owner’s
directory.
Sourcefn loan_sequence(&self) -> Result<u32>
fn loan_sequence(&self) -> Result<u32>
A sequential identifier for Loan ledger entires, incremented each time a new loan is
created by this LoanBroker.
Sourcefn data(&self) -> Result<Option<StandardBlob>>
fn data(&self) -> Result<Option<StandardBlob>>
Arbitrary metadata about the vault. Limited to 256 bytes.
Sourcefn management_fee_rate(&self) -> Result<Option<u16>>
fn management_fee_rate(&self) -> Result<Option<u16>>
The fee charged by the lending protocol on any loan interest, in units of 1/10th basis points. Valid values are 0 to 10000 (inclusive), representing 0% to 10%.
Sourcefn owner_count(&self) -> Result<Option<u32>>
fn owner_count(&self) -> Result<Option<u32>>
The number of active loans issued by the LoanBroker.
Sourcefn debt_total(&self) -> Result<Option<Number>>
fn debt_total(&self) -> Result<Option<Number>>
The total asset amount the protocol owes the vault, including interest.
Sourcefn debt_maximum(&self) -> Result<Option<Number>>
fn debt_maximum(&self) -> Result<Option<Number>>
The maximum amount the protocol can owe the vault. The default value of 0 means there is
no limit to the debt.
Sourcefn cover_available(&self) -> Result<Option<Number>>
fn cover_available(&self) -> Result<Option<Number>>
The total amount of first-loss capital deposited into the lending protocol.
Sourcefn cover_rate_minimum(&self) -> Result<Option<u32>>
fn cover_rate_minimum(&self) -> Result<Option<u32>>
The 1/10th basis point of the DebtTotal that the first-loss capital must cover. Valid
values are 0 to 100000 (inclusive), representing 0% to 100%.
Sourcefn cover_rate_liquidation(&self) -> Result<Option<u32>>
fn cover_rate_liquidation(&self) -> Result<Option<u32>>
The 1/10th basis point of minimum required first-loss capital that is moved to an asset vault to cover a loan default. Valid values are 0 to 100000 (inclusive), representing 0% to 100%.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".