pub trait CurrentXChainOwnedCreateAccountClaimIDFields: CurrentLedgerObjectCommonFields {
// Provided methods
fn account(&self) -> Result<AccountID> { ... }
fn xchain_bridge(&self) -> Result<[u8; 512]> { ... }
fn xchain_account_create_count(&self) -> Result<u64> { ... }
fn owner_node(&self) -> Result<u64> { ... }
fn previous_txn_id(&self) -> Result<Hash256> { ... }
fn previous_txn_lgr_seq(&self) -> Result<u32> { ... }
}Expand description
Trait providing access to fields specific to the current XChainOwnedCreateAccountClaimID object.
Provided Methods
Sourcefn xchain_bridge(&self) -> Result<[u8; 512]>
fn xchain_bridge(&self) -> Result<[u8; 512]>
The door accounts and assets of the bridge this object correlates to. Raw bytes; XCHAIN_BRIDGE is not yet typed in Rust.
Sourcefn xchain_account_create_count(&self) -> Result<u64>
fn xchain_account_create_count(&self) -> Result<u64>
An integer that determines the order that accounts created through cross-chain transfers must be performed. Smaller numbers must execute before larger numbers.
Sourcefn owner_node(&self) -> Result<u64>
fn owner_node(&self) -> Result<u64>
The OwnerNode field (Required).
Sourcefn previous_txn_id(&self) -> Result<Hash256>
fn previous_txn_id(&self) -> Result<Hash256>
The PreviousTxnID field (Required).
Sourcefn previous_txn_lgr_seq(&self) -> Result<u32>
fn previous_txn_lgr_seq(&self) -> Result<u32>
The PreviousTxnLgrSeq field (Required).
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".