pub trait DepositPreauthFields: LedgerObjectCommonFields {
// Provided methods
fn account(&self) -> Result<AccountID> { ... }
fn authorize(&self) -> Result<Option<AccountID>> { ... }
fn owner_node(&self) -> Result<u64> { ... }
fn previous_txn_id(&self) -> Result<Hash256> { ... }
fn previous_txn_lgr_seq(&self) -> Result<u32> { ... }
}Expand description
Trait providing access to fields specific to DepositPreauth objects in any ledger.
Provided Methods
Sourcefn account(&self) -> Result<AccountID>
fn account(&self) -> Result<AccountID>
The account that granted the preauthorization. (The destination of the preauthorized payments.)
The account that received the preauthorization. (The sender of the preauthorized payments.)
Sourcefn owner_node(&self) -> Result<u64>
fn owner_node(&self) -> Result<u64>
A hint indicating which page of the sender’s owner directory links to this object, in case
the directory consists of multiple pages. Note: The object does not contain a direct link to
the owner directory containing it, since that value can be derived from the Account.
Sourcefn previous_txn_id(&self) -> Result<Hash256>
fn previous_txn_id(&self) -> Result<Hash256>
The identifying hash of the transaction that most recently modified this object.
Sourcefn previous_txn_lgr_seq(&self) -> Result<u32>
fn previous_txn_lgr_seq(&self) -> Result<u32>
The index of the ledger that contains the transaction that most recently modified this object.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".