pub trait LoanFields: LedgerObjectCommonFields {
Show 27 methods
// Provided methods
fn previous_txn_id(&self) -> Result<Hash256> { ... }
fn previous_txn_lgr_seq(&self) -> Result<u32> { ... }
fn owner_node(&self) -> Result<u64> { ... }
fn loan_broker_node(&self) -> Result<u64> { ... }
fn loan_broker_id(&self) -> Result<Hash256> { ... }
fn loan_sequence(&self) -> Result<u32> { ... }
fn borrower(&self) -> Result<AccountID> { ... }
fn loan_origination_fee(&self) -> Result<Option<Number>> { ... }
fn loan_service_fee(&self) -> Result<Option<Number>> { ... }
fn late_payment_fee(&self) -> Result<Option<Number>> { ... }
fn close_payment_fee(&self) -> Result<Option<Number>> { ... }
fn overpayment_fee(&self) -> Result<Option<u32>> { ... }
fn interest_rate(&self) -> Result<Option<u32>> { ... }
fn late_interest_rate(&self) -> Result<Option<u32>> { ... }
fn close_interest_rate(&self) -> Result<Option<u32>> { ... }
fn overpayment_interest_rate(&self) -> Result<Option<u32>> { ... }
fn start_date(&self) -> Result<u32> { ... }
fn payment_interval(&self) -> Result<u32> { ... }
fn grace_period(&self) -> Result<Option<u32>> { ... }
fn previous_payment_due_date(&self) -> Result<Option<u32>> { ... }
fn next_payment_due_date(&self) -> Result<Option<u32>> { ... }
fn payment_remaining(&self) -> Result<Option<u32>> { ... }
fn periodic_payment(&self) -> Result<Number> { ... }
fn principal_outstanding(&self) -> Result<Option<Number>> { ... }
fn total_value_outstanding(&self) -> Result<Option<Number>> { ... }
fn management_fee_outstanding(&self) -> Result<Option<Number>> { ... }
fn loan_scale(&self) -> Result<Option<i32>> { ... }
}Expand description
Trait providing access to fields specific to Loan objects in any ledger.
Provided Methods
Sourcefn previous_txn_id(&self) -> Result<Hash256>
fn previous_txn_id(&self) -> Result<Hash256>
Identifies the transaction ID that most recently modified this object.
Sourcefn previous_txn_lgr_seq(&self) -> Result<u32>
fn previous_txn_lgr_seq(&self) -> Result<u32>
The sequence of the ledger that contains the transaction that most recently modified this object.
Sourcefn owner_node(&self) -> Result<u64>
fn owner_node(&self) -> Result<u64>
Identifies the page where this item is referenced in the owner’s directory.
Sourcefn loan_broker_node(&self) -> Result<u64>
fn loan_broker_node(&self) -> Result<u64>
Identifies the page where this item is referenced in the LoanBroker owner directory.
Sourcefn loan_broker_id(&self) -> Result<Hash256>
fn loan_broker_id(&self) -> Result<Hash256>
The ID of the Loan Broker associated with this loan.
Sourcefn loan_sequence(&self) -> Result<u32>
fn loan_sequence(&self) -> Result<u32>
The sequence number of the loan.
Sourcefn loan_origination_fee(&self) -> Result<Option<Number>>
fn loan_origination_fee(&self) -> Result<Option<Number>>
The amount paid to the Loan Broker, taken from the principal loan at creation.
Sourcefn loan_service_fee(&self) -> Result<Option<Number>>
fn loan_service_fee(&self) -> Result<Option<Number>>
The amount paid to the Loan Broker with each loan payment.
Sourcefn late_payment_fee(&self) -> Result<Option<Number>>
fn late_payment_fee(&self) -> Result<Option<Number>>
The amount paid to the Loan Broker for each late payment.
Sourcefn close_payment_fee(&self) -> Result<Option<Number>>
fn close_payment_fee(&self) -> Result<Option<Number>>
The amount paid to the Loan Broker when a full early payment is made.
Sourcefn overpayment_fee(&self) -> Result<Option<u32>>
fn overpayment_fee(&self) -> Result<Option<u32>>
The fee charged on overpayments, in units of 1/10th basis points. Valid values are 0 to 100000 (inclusive), representing 0% to 100%.
Sourcefn interest_rate(&self) -> Result<Option<u32>>
fn interest_rate(&self) -> Result<Option<u32>>
The annualized interest rate of the loan, in 1/10th basis points.
Sourcefn late_interest_rate(&self) -> Result<Option<u32>>
fn late_interest_rate(&self) -> Result<Option<u32>>
The premium added to the interest rate for late payments, in units of 1/10th basis points. Valid values are 0 to 100000 (inclusive), representing 0% to 100%.
Sourcefn close_interest_rate(&self) -> Result<Option<u32>>
fn close_interest_rate(&self) -> Result<Option<u32>>
The interest rate charged for repaying the loan early, in units of 1/10th basis points. Valid values are 0 to 100000 (inclusive), representing 0% to 100%.
Sourcefn overpayment_interest_rate(&self) -> Result<Option<u32>>
fn overpayment_interest_rate(&self) -> Result<Option<u32>>
The interest rate charged on overpayments, in units of 1/10th basis points. Valid values are 0 to 100000 (inclusive), representing 0% to 100%.
Sourcefn start_date(&self) -> Result<u32>
fn start_date(&self) -> Result<u32>
The timestamp of when the loan started, in seconds since the Ripple Epoch.
Sourcefn payment_interval(&self) -> Result<u32>
fn payment_interval(&self) -> Result<u32>
The number of seconds between loan payments.
Sourcefn grace_period(&self) -> Result<Option<u32>>
fn grace_period(&self) -> Result<Option<u32>>
The number of seconds after a loan payment is due before the loan defaults.
Sourcefn previous_payment_due_date(&self) -> Result<Option<u32>>
fn previous_payment_due_date(&self) -> Result<Option<u32>>
The timestamp of when the previous payment was made, in seconds since the Ripple Epoch.
Sourcefn next_payment_due_date(&self) -> Result<Option<u32>>
fn next_payment_due_date(&self) -> Result<Option<u32>>
The timestamp of when the next payment is due, in seconds since the Ripple Epoch.
Sourcefn payment_remaining(&self) -> Result<Option<u32>>
fn payment_remaining(&self) -> Result<Option<u32>>
The number of payments remaining on the loan.
Sourcefn periodic_payment(&self) -> Result<Number>
fn periodic_payment(&self) -> Result<Number>
The amount due for each payment interval.
Sourcefn principal_outstanding(&self) -> Result<Option<Number>>
fn principal_outstanding(&self) -> Result<Option<Number>>
The principal amount still owed on the loan.
Sourcefn total_value_outstanding(&self) -> Result<Option<Number>>
fn total_value_outstanding(&self) -> Result<Option<Number>>
The total amount owed on the loan, including remaining principal and fees.
Sourcefn management_fee_outstanding(&self) -> Result<Option<Number>>
fn management_fee_outstanding(&self) -> Result<Option<Number>>
The remaining management fee owed to the loan broker.
Sourcefn loan_scale(&self) -> Result<Option<i32>>
fn loan_scale(&self) -> Result<Option<i32>>
The scale factor that ensures all computed amounts are rounded to the same number of decimal places. It is based on the total loan value at creation time.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".