pub trait NFTokenPageFields: LedgerObjectCommonFields {
// Provided methods
fn previous_page_min(&self) -> Result<Option<Hash256>> { ... }
fn next_page_min(&self) -> Result<Option<Hash256>> { ... }
fn previous_txn_id(&self) -> Result<Hash256> { ... }
fn previous_txn_lgr_seq(&self) -> Result<u32> { ... }
}Expand description
Trait providing access to fields specific to NFTokenPage objects in any ledger.
Provided Methods
Sourcefn previous_page_min(&self) -> Result<Option<Hash256>>
fn previous_page_min(&self) -> Result<Option<Hash256>>
The locator of the previous page, if any. Details about this field and how it should be used are outlined below.
Sourcefn next_page_min(&self) -> Result<Option<Hash256>>
fn next_page_min(&self) -> Result<Option<Hash256>>
The locator of the next page, if any. Details about this field and how it should be used are outlined below.
Sourcefn previous_txn_id(&self) -> Result<Hash256>
fn previous_txn_id(&self) -> Result<Hash256>
Identifies the transaction ID of the transaction that most recently modified this NFTokenPage object.
Sourcefn previous_txn_lgr_seq(&self) -> Result<u32>
fn previous_txn_lgr_seq(&self) -> Result<u32>
The sequence of the ledger that contains the transaction that most recently modified this NFTokenPage object.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".