pub trait RippleStateFields: LedgerObjectCommonFields {
Show 13 methods
// Provided methods
fn balance(&self) -> Result<Amount> { ... }
fn low_limit(&self) -> Result<Amount> { ... }
fn high_limit(&self) -> Result<Amount> { ... }
fn previous_txn_id(&self) -> Result<Hash256> { ... }
fn previous_txn_lgr_seq(&self) -> Result<u32> { ... }
fn low_node(&self) -> Result<Option<u64>> { ... }
fn low_quality_in(&self) -> Result<Option<u32>> { ... }
fn low_quality_out(&self) -> Result<Option<u32>> { ... }
fn high_node(&self) -> Result<Option<u64>> { ... }
fn high_quality_in(&self) -> Result<Option<u32>> { ... }
fn high_quality_out(&self) -> Result<Option<u32>> { ... }
fn high_sponsor(&self) -> Result<Option<AccountID>> { ... }
fn low_sponsor(&self) -> Result<Option<AccountID>> { ... }
}Expand description
Trait providing access to fields specific to RippleState objects in any ledger.
Provided Methods
Sourcefn balance(&self) -> Result<Amount>
fn balance(&self) -> Result<Amount>
The balance of the trust line, from the perspective of the low account. A negative balance indicates that the high account holds tokens issued by the low account. The issuer in this is always set to the neutral value ACCOUNT_ONE.
Sourcefn low_limit(&self) -> Result<Amount>
fn low_limit(&self) -> Result<Amount>
The limit that the low account has set on the trust line. The issuer is the address of the
low account that set this limit.
Sourcefn high_limit(&self) -> Result<Amount>
fn high_limit(&self) -> Result<Amount>
The limit that the high account has set on the trust line. The issuer is the address of
the high account that set this limit.
Sourcefn previous_txn_id(&self) -> Result<Hash256>
fn previous_txn_id(&self) -> Result<Hash256>
The identifying hash of the transaction that most recently modified this entry.
Sourcefn previous_txn_lgr_seq(&self) -> Result<u32>
fn previous_txn_lgr_seq(&self) -> Result<u32>
The index of the ledger that contains the transaction that most recently modified this entry.
Sourcefn low_node(&self) -> Result<Option<u64>>
fn low_node(&self) -> Result<Option<u64>>
(Omitted in some historical ledgers) A hint indicating which page of the low account’s owner directory links to this entry, in case the directory consists of multiple pages.
Sourcefn low_quality_in(&self) -> Result<Option<u32>>
fn low_quality_in(&self) -> Result<Option<u32>>
The inbound quality set by the low account, as an integer in the implied ratio
LowQualityIn:1,000,000,000. As a special case, the value 0 is equivalent to 1 billion, or
face value.
Sourcefn low_quality_out(&self) -> Result<Option<u32>>
fn low_quality_out(&self) -> Result<Option<u32>>
The outbound quality set by the low account, as an integer in the implied ratio
LowQualityOut:1,000,000,000. As a special case, the value 0 is equivalent to 1 billion, or
face value.
Sourcefn high_node(&self) -> Result<Option<u64>>
fn high_node(&self) -> Result<Option<u64>>
(Omitted in some historical ledgers) A hint indicating which page of the high account’s owner directory links to this entry, in case the directory consists of multiple pages.
Sourcefn high_quality_in(&self) -> Result<Option<u32>>
fn high_quality_in(&self) -> Result<Option<u32>>
The inbound quality set by the high account, as an integer in the implied ratio
HighQualityIn:1,000,000,000. As a special case, the value 0 is equivalent to 1 billion, or
face value.
Sourcefn high_quality_out(&self) -> Result<Option<u32>>
fn high_quality_out(&self) -> Result<Option<u32>>
The outbound quality set by the high account, as an integer in the implied ratio
HighQualityOut:1,000,000,000. As a special case, the value 0 is equivalent to 1 billion,
or face value.
Sourcefn high_sponsor(&self) -> Result<Option<AccountID>>
fn high_sponsor(&self) -> Result<Option<AccountID>>
The sponsor paying the reserve on behalf of the high account on the trust line. This is
separate from LowSponsor because bidirectional trust lines may have the reserve held by
two accounts.
Sourcefn low_sponsor(&self) -> Result<Option<AccountID>>
fn low_sponsor(&self) -> Result<Option<AccountID>>
The sponsor paying the reserve on behalf of the low account on the trust line. This is
separate from HighSponsor because bidirectional trust lines may have the reserve held by
two accounts.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".