VaultFields

Trait VaultFields 

pub trait VaultFields: LedgerObjectCommonFields {
Show 16 methods // Provided methods fn previous_txn_id(&self) -> Result<Hash256> { ... } fn previous_txn_lgr_seq(&self) -> Result<u32> { ... } fn sequence(&self) -> Result<u32> { ... } fn owner_node(&self) -> Result<u64> { ... } fn owner(&self) -> Result<AccountID> { ... } fn account(&self) -> Result<AccountID> { ... } fn data(&self) -> Result<Option<StandardBlob>> { ... } fn asset(&self) -> Result<Issue> { ... } fn assets_total(&self) -> Result<Option<Number>> { ... } fn assets_available(&self) -> Result<Option<Number>> { ... } fn assets_maximum(&self) -> Result<Option<Number>> { ... } fn loss_unrealized(&self) -> Result<Option<Number>> { ... } fn share_mpt_id(&self) -> Result<Hash192> { ... } fn withdrawal_policy(&self) -> Result<u8> { ... } fn scale(&self) -> Result<Option<u8>> { ... } fn le_version(&self) -> Result<Option<u8>> { ... }
}
Trait providing access to fields specific to Vault objects in any ledger.

Provided Methods

fn previous_txn_id(&self) -> Result<Hash256>

Identifies the transaction ID that most recently modified this object.

fn previous_txn_lgr_seq(&self) -> Result<u32>

The sequence of the ledger that contains the transaction that most recently modified this object.

fn sequence(&self) -> Result<u32>

The transaction sequence number that created the vault.

fn owner_node(&self) -> Result<u64>

Identifies the page where this item is referenced in the owner’s directory.

fn owner(&self) -> Result<AccountID>

The account address of the Vault Owner.

fn account(&self) -> Result<AccountID>

The address of the vault’s pseudo-account.

fn data(&self) -> Result<Option<StandardBlob>>

Arbitrary metadata, in hex format, about the vault. Limited to 256 bytes. See Data Field Format for more information.

fn asset(&self) -> Result<Issue>

The asset of the vault. The vault supports XRP, trust line tokens, and MPTs.

fn assets_total(&self) -> Result<Option<Number>>

The total value of the vault.

fn assets_available(&self) -> Result<Option<Number>>

The asset amount that is available in the vault.

fn assets_maximum(&self) -> Result<Option<Number>>

The maximum asset amount that can be held in the vault. If set to 0, this indicates there is no cap.

fn loss_unrealized(&self) -> Result<Option<Number>>

The potential loss amount that is not yet realized, expressed as the vault’s asset. Only a protocol connected to the vault can modify this attribute.

fn share_mpt_id(&self) -> Result<Hash192>

The identifier of the share MPTokenIssuance object.

fn withdrawal_policy(&self) -> Result<u8>

Indicates the withdrawal strategy used by the vault.

fn scale(&self) -> Result<Option<u8>>

Specifies decimal precision for share calculations. Assets are multiplied by 10^Scale to convert fractional amounts into whole number shares. For example, with a Scale of 6, depositing 20.3 units creates 20,300,000 shares (20.3 × 10^Scale). For trust line tokens this can be configured at vault creation, and valid values are between 0-18, with the default being 6. For XRP and MPTs, this is fixed at 0. See Scaling Factor for more information.

fn le_version(&self) -> Result<Option<u8>>

The LEVersion field (Optional).

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors